#
# spec file for package panoply
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           panoply
Version:        4.12.2
Release:        1.1
Summary:        A netCDF, HDF and GRIB Data Viewer
License:        Unlicense AND MIT AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause
Group:          Productivity/Scientific/Other
URL:            https://www.giss.nasa.gov/tools/panoply
Source0:        https://www.giss.nasa.gov/tools/panoply/download/PanoplyJ-%{version}.zip
Source1:        EdGCM_Panoply.pdf
Source2:        panoply_D.pdf
Source3:        %{name}.desktop
Source4:        panoply.png
BuildRequires:  unzip
Requires:       java >= 1.9.0
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
%endif
BuildArch:      noarch

%description
Panoply is a cross-platform application that plots geo-referenced and other
arrays from netCDF, HDF, GRIB, and other datasets.
With Panoply 4 you can:
 * Slice and plot geo-referenced latitude-longitude, latitude-vertical,
     longitude-vertical, time-latitude or time-vertical arrays from
     larger multidimensional variables.
 * Slice and plot "generic" 2D arrays from larger multidimensional variables.
 * Slice 1D arrays from larger multidimensional variables and create line plots.
 * Combine two geo-referenced arrays in one plot by differencing, summing or
     averaging.
 * Plot lon-lat data on a global or regional map using any of over 100 map
     projections or make a zonal average line plot.
 * Overlay continent outlines or masks on lon-lat map plots.
 * Use any of numerous color tables for the scale colorbar, or apply your own
     custom ACT, CPT, or RGB color table.
 * Save plots to disk GIF, JPEG, PNG or TIFF bitmap images or as PDF or
     PostScript graphics files.
 * Export lon-lat map plots in KMZ format.
 * Export animations as AVI or MOV video or as a collection of invididual frame
     images.
 * Explore remote THREDDS and OpenDAP catalogs and open datasets served
     from them.

%prep
rm -fr PanoplyJ
unzip %{SOURCE0}

%build

%install
# startscript
cat > %{name} << 'EOF'
#!/bin/sh
#
# panoply startscript
#

java -Xms512m -Xmx1600m -jar %{_datadir}/%{name}/Panoply.jar "$@"

EOF
install -d -m 755 %{buildroot}%{_bindir}
install -m 755 %{name} %{buildroot}%{_bindir}/
install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -m 644 PanoplyJ/jars/* %{buildroot}%{_datadir}/%{name}/
install -d -m 755 %{buildroot}%{_datadir}/applications/
install -m 644 %{SOURCE3} %{buildroot}%{_datadir}/applications/
install -d -m 755 %{buildroot}%{_datadir}/icons/hicolor/192x192/apps/
install -m 644 %{SOURCE4} %{buildroot}%{_datadir}/icons/hicolor/192x192/apps/
install -d -m 755 %{buildroot}%{_defaultdocdir}/%{name}
install -m 644 PanoplyJ/README.txt %{buildroot}%{_defaultdocdir}/%{name}/
install -m 644 %{SOURCE1} %{buildroot}%{_defaultdocdir}/%{name}/
install -m 644 %{SOURCE2} %{buildroot}%{_defaultdocdir}/%{name}/
%if 0%{?suse_version}
%suse_update_desktop_file %{name}
%endif

%if 0%{?suse_version}
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%{_defaultdocdir}/%{name}/
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/applications/
%{_datadir}/icons/hicolor/

%changelog
* Sun Dec 27 2020 Manfred Schwarb <manfred99@gmx.ch>
- update to version 4.12.2
  * for changelog see https://www.giss.nasa.gov/tools/panoply/versions.html
- require Java 9
* Tue Jun  9 2020 Edward Baudrez <edward.baudrez@gmail.com>
- update to version 4.11.3
  * for changelog see https://www.giss.nasa.gov/tools/panoply/versions.html
- improved desktop integration with GNOME/KDE
* Tue Dec  3 2019 manfred99@gmx.ch
- update to version 4.10.11
  * for changelog see https://www.giss.nasa.gov/tools/panoply/versions.html
* Thu Jan 19 2017 manfred99@gmx.ch
- update to version 4.6.2:
  * Scale colorbar's border stroke now scales with plot size.
  * Added left and right footnote options to plot label controls for, e.g., including credit info.
  * Added ability to specify formatting for min-max footnote values different from scale tickmark format.
  * Library: Updated Apache Commons Lang to v. 3.5.
  * Added MP4 (via JCodec library) to choices for exporting animations.
  * Library: Updated GISSmap to v. 1.8.4.
- update to version 4.6.1:
  * Bugfix: Generic 2D plotting of HDF data blocked if either dimension unnamed.
  * Bugfix: Horizontal rendering artifacts could appear when drawing line plots with a large number of points.
  * Bugfix: Launch/Open panel missing from prefs.
  * Bugfix: Symbol size for point shapefile map overlays did not scale with plot size.
  * Added controls and preferences for specifying symbol size when using point shapefile map overlay.
  * Added more options to animation export dialog, including start, stop and stride.
  * Library: Updated netCDF-Java to v. 4.6.7 (snapshot).
  * Bugfix: (macOS) App would not launch if a Java 9 early-access JRE or JDK installed.
  * Further test to ensure that trajectory data not mistakenly identified as lon-lat gridded.
  * Bugfix: CDL data export for an individual variable failed if var in a hierarchical group.
* Fri Sep  2 2016 manfred99@gmx.ch
- update to version 4.6.0:
  * Improved window-size management for Sources and Help windows in multi-display set-up with different display sizes.
  * Improved window management when exporting display via X11.
  * Library: Updated slf4j to v. 1.7.21.
  * Library: Updated netCDF-Java to v. 4.6.6.
  * Bugfix: Could not create combination plot if second var was on reduced-horizontal grid.
  * Bugfix: Lat-, lon- and time-vert plots always initialized with scalar vert axis, ignoring preference setting.
  * Bugfix: KMZ plot exports included border even when de-selected.
  * Implemented zooming (in, out and drag) for all non-lon-lat plot types.
  * Re-organized layout of scale and grid controls for all plot types, adding axis range controls in cases where they were not previously available and adding menu commands to swap and reset axis range bounds.
  * Better handling of fill and valid range attributes for unsigned int variables when expressed as negatives.
  * Added preference to set whether Y-axis orientation of generic 2D plots is positive up or down.
  * Watch for "double enhanced" coordinate variables when extracting CDL text to show in sources info panel.
  * Added support for cylindrical equal-area projected lon-lat input grids.
  * Hairlines added to crosshairs cursor.
  * Bugfix: Uninterpolated generic 2D plot could be blank if log-10 axis selected and axis had negative endpoint.
* Thu Jun  2 2016 manfred99@gmx.ch
- update to version 4.5.1:
  * Bugfix: Plot title too low if subtitle also present.
  * Bugfix: (OS X) Crash at launch if JRE not found in expected location.
  * Further improved recognition and handling of lon-lat data using 3D auxiliary grids.
  * Bugfix: Click-for-info on non-lon-lat 2D plots had redundant margin offset.
  * Bugfix: Wrong coordinate var might be reported if correct var's name did not case-wise match dimension name.
- update to version 4.5:
  * Bugfix: Speckling effect in interpolated plots of data on reduced horizontal grid.
  * Click-for-info now implemented for plots based on data on reduced horizontal grid.
  * Data table tab panel now displays values for data on reduced horizontal grid.
  * Added ability to plot ISCCP equal-area grid abased on similarities to CF reduced horizontal grid convention.
  * Bugfix: Possible axes swap for swath data in HDF-5 datasets if using unnamed dimensions of equal length.
  * Refactored variable coordinates analysis to reduce redundant code and to improve detection of georeferencing when not reported by NJ library code.
  * Bugfix: CPT color tables with unparseable color data were not rejected, which caused later trouble when trying to use them.
  * Revised handling of colorbar tick size menu choices.
  * Contour label text scales with plot size similarly to other text.
  * Bugfix: Possible (silent) null pointer exception when using link dialog with a combination plot.
  * Thoroughly rewrote line plot code to better display data with a large number (> 1000) of steps on the plot axis. Implemented Ramer-Douglas-Peucker simplification for the case of there being a very large number (> 10000) of steps.
  * Library: Updated netCDF-Java to v. 4.6.5.
  * Library: (OS X) Updated Java OS X launcher to March 16 Infinite Kind appbundler commit.
  * Bugfix: Gridding bounds did not reset when toggling from zonal average plot to a regional map plot.
  * Implemented additional buffering to reduce plot redraws and improve interface response.
  * CPT color table constructor uses min and max colors for below-min and above-max outliers iff no outlier colors defined in file.
  * Bugfix: Floating-point error of order 1E-8 when interpolating between four points with identical value.
* Tue Apr 19 2016 manfred99@gmx.ch
- update to version 4.4.3:
  * Bugfix: "All files" filter not working in open-file chooser for non-OS X systems.
  * Bugfix: Localization problem when saving extra map projection parameters to preferences.
  * Library: Updated netCDF-Java to v. 4.6.4.
  * Bugfix: Grid labels for generic 2D displayed default values even if user chose alternative units.
  * Additional ability to detect data on auxiliary lon-lat grid even if NJ library failed to dtect a coordinate system.
  * Bugfix: Possible silent failure to report presence of variables in HDF-5 datasets if they used unnamed dimensions.
- update to version 4.4.2:
  * Refactored filechooser construction and (OS X) replaced JNI/libpanoply native library with more general JNI/libgiss.
  * Added control to change data table display row and column titles from grid value to grid index.
  * Bugfix: Display of 1D data table did not respond to flip-L/R control.
  * Display of 1D data table modified to match vertical vs horizontal plot axis orientation.
  * Improved handling of lon-lat data using 3D auxiliary grids.
  * Added tests for data axes that are not monotonic, and therefore not suited to be plotted by Panoply.
  * Library: Updated GISSmap to v. 1.8.3.
* Mon Jan 11 2016 manfred99@gmx.ch
- update to version 4.4.1:
  * Bugfix: Printf code result could be incorrect if "%%.pf" format used and the formatted number was larger than 1E7.
  * Added "Use Default" buttons to X and/or Y grid axis range controls for various plot types.
  * Tweaked determination of time format string used in independent dimension controls.
  * Added control for weight of border on lon-lat map plots.
  * Bugfix: Change in lon-lat map projection could be double-fired.
  * Restored drag-and-drop functionality of colorbars and overlays from desktop into plot windows and into colorbar and overlay browsers.
  * Library: Updated GISSmap to v. 1.8.2
  * Bugfix: Zoom-out action might not be enabled for map plots when it should be.
* Sun Dec 13 2015 manfred99@gmx.ch
- update to version 4.4:
  * Bugfix: Possible thread deadlock when drag-and-dropping color table file icon from desktop into color table prefs panel.
  * Optionally include scale colorbar when exporting KMZ file of map plot.
  * Bugfix: Line plot elements could be drawn outside scroll panel if plot larger than plot window size.
  * Pressing delete in sources browser invokes remove action (if enabled) for selected node.
  * Refactored all 2D plot types and backing data grids (except lon-lat maps) to simplify and reduce redundant code.
  * Added vertical line plotting.
  * Refactored horizontal line plotting to share common code with vertical line plotting.
  * Refactored all scale controls to reduce redundant code.
  * Horizontal line plots may have logarithmic scale.
  * Added menu options for controlling width of central plot area relative to total width, allowing for wider left and right margins.
  * Bugfix: Size of logarithmic ticks on a scale colorbar did not scale with plot size.
  * Library: Updated GISSmap to v. 1.8.1.
  * Added link button to grid-spacing controls for lon-lat map plot.
  * Include labeled sample stroke in lon-lat zonal average line plots.
  * Removed (optional) inclusion of map projection footnote from lon-lat map plots.
  * Bugfix: Array combinations in line plots could only be created using drag-and-drop.
* Sat Nov 14 2015 manfred99@gmx.ch
- update to version 4.3.2:
  * Bugfix: CPT color table handler ignored background and foreground (i.e., outlier) color definitions if present.
  * Bugfix: Array construction failed for generic 2D plots of HDF data with unnamed dimensions of equal length.
  * Bugfix: Continued decimal character localization problem with some map projection parameter settings.
  * Lon-lat vector plots may be made combining component variables of magnitude and azimuth.
  * Bugfix: Right edge of map plots of projected-grid data might show a strip of missing data where there is good data.
* Mon Oct  5 2015 manfred99@gmx.ch
- spec-cleaner changes
- update to version 4.3.1:
  * Refactored messaging from plot controls of changes to X- and Y-axis method and range settings.
  * Bugfix: Y-axis top value could not be less than bottom value for line plots.
  * Bugfix: Possible thread conflict when exporting an animation of a plot with contours.
  * Added preference option to disable sorting items in Sources datasets panel alphabetically.
  * Library: Updated netCDF-Java to v. 4.6.3.
  * Library: Updated GISSmap to v. 1.8.0.
  * Bugfix: Sources tree-table did not show/hide structure variables in respond to change of visible variable setting.
